==> bow-ui-0.5-sources.jar: org/chorem/bow/interceptor/LoginInterceptor.java <==
/*
 * #%L
 * bow
 * 
 * $Id: LoginInterceptor.java 232 2011-03-10 11:29:17Z sletellier $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-0.5/bow-ui/src/main/java/org/chorem/bow/interceptor/LoginInterceptor.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.interceptor;

import java.util.Map;

import org.apache.struts2.ServletActionContext;
import org.chorem.bow.BowUtils;
import org.chorem.bow.BowUser;

import com.opensymphony.xwork2.ActionContext;
import com.opensymphony.xwork2.ActionInvocation;
import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
import org.chorem.bow.BowSession;

/**
 * Interceptor used to redirect a non-logged user if he tries to access a page 
 * where logging is mandatory
 */
public class LoginInterceptor extends AbstractInterceptor {
    private static final long serialVersionUID = -7520186185205372272L;
    protected String redirect;

    /**
     * @param redirect the redirect to set
     */
    public void setRedirect(String redirect) {
        this.redirect = redirect;
    }

    @Override
    public String intercept(ActionInvocation invocation) throws Exception {
        Map<String, Object> session = ActionContext.getContext().getSession();

        BowSession bowSession = BowSession.getBowSession(session);
        BowUser user = bowSession.getUser();
        String result = invocation.invoke();

        //If the user isn't logged in
        if (user == null) {
            Map<String, Object> params = ActionContext.getContext().getParameters();
            //Retrieves the token value in URL
            String[] token = (String[]) params.get("token");

            if (token != null && !token[0].isEmpty()) {
                //Retrieves the user by token
                user = BowUtils.checkToken(bowSession, token[0]);

                //If the token is valid
                if (user != null) {
                    //Authenticates the user
                    bowSession.setUser(user);
                }
            } else {
                //If the token is empty
                ServletActionContext.getResponse().sendRedirect(redirect);
                result = null;
            }
        }
        return result;
    }
}

==> bow-ui-1.0-sources.jar: org/chorem/bow/interceptor/LoginInterceptor.java <==
/*
 * #%L
 * bow
 * 
 * $Id: LoginInterceptor.java 276 2011-04-29 21:02:55Z bpoussin $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.0/bow-ui/src/main/java/org/chorem/bow/interceptor/LoginInterceptor.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.interceptor;

import java.util.Map;

import org.apache.struts2.ServletActionContext;
import org.chorem.bow.BowUtils;
import org.chorem.bow.BowUser;

import com.opensymphony.xwork2.ActionContext;
import com.opensymphony.xwork2.ActionInvocation;
import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
import org.chorem.bow.BowSession;

/**
 * Interceptor used to redirect a non-logged user if he tries to access a page 
 * where logging is mandatory
 */
public class LoginInterceptor extends AbstractInterceptor {
    private static final long serialVersionUID = -7520186185205372272L;
    protected String redirect;

    /**
     * @param redirect the redirect to set
     */
    public void setRedirect(String redirect) {
        this.redirect = redirect;
    }

    @Override
    public String intercept(ActionInvocation invocation) throws Exception {
        Map<String, Object> session = ActionContext.getContext().getSession();

        BowSession bowSession = BowSession.getBowSession(session);
        BowUser user = bowSession.getUser();
        String result = null;
        
        //If the user isn't logged in
        if (user == null) {
            Map<String, Object> params = ActionContext.getContext().getParameters();
            //Retrieves the token value in URL
            String[] token = (String[]) params.get("token");

            if (token != null && !token[0].isEmpty()) {
                //Retrieves the user by token
                user = BowUtils.checkToken(bowSession, token[0]);

                //If the token is valid
                if (user != null) {
                    //Authenticates the user
                    bowSession.setUser(user);
                }
            }
        }

        if (user == null) {
            ServletActionContext.getResponse().sendRedirect(redirect);
        } else {
            result = invocation.invoke();
        }

        return result;
    }
}
